@@ -15,7 +15,7 @@ class MachineWrapper(object):
         "ssh_internal_port",
         "external_hostname",
         "is_running",
-        "public_port",
+        "forwarded_tcp_ports",
         "destroy",
         "users",
     ]
@@ -24,6 +24,9 @@ class MachineWrapper(object):
         self._machine = machine
         for delegate in self._delegates:
             setattr(self, delegate, getattr(self._machine, delegate))
+        
+    def public_port(self, guest_port):
+        return self.forwarded_tcp_ports().get(guest_port, None)
     
     def __enter__(self):
         return self
@@ -84,3 +87,26 @@ class MachineWrapper(object):
             
         return filter(condition, self.users())[0]
         
+
+class MachineSet(object):
+    def __init__(self, machines):
+        self._machines = machines
+        
+    def __enter__(self):
+        return self
+        
+    def __exit__(self, *args):
+        for machine in self._machines:
+            machine.destroy()
+            
+    def __getitem__(self, key):
+        if isinstance(key, basestring):
+            return next(
+                machine
+                for machine in self._machines
+                if machine.name == key
+            )
+        elif isinstance(key, (int, long)):
+            return self._machines[key]
+        else:
+            raise TypeError("Expected key to be string or integer")
